@@ -1,6 +1,6 @@
 package Math::Prime::Simple;
 
-$VERSION = '0.09';
+$VERSION = '0.10';
 @EXPORT_OK = qw(prime each_prime);
 
 use strict 'vars';
@@ -21,7 +21,7 @@ Math::Prime::Simple - Calculate prime numbers
  );
 
  # primes calculation
- $primes = prime( \@ranges );
+ $primes = prime( @ranges );
 
  # primes iteration
  while ($prime = each_prime( 0, $primes )) {
@@ -42,7 +42,7 @@ Calculates prime numbers.
              [ 10000, 11000 ],
  );
 
- $primes = prime( \@ranges );
+ $primes = prime( @ranges );
 
 Each range within @ranges will be evaluated and its prime numbers will be
 saved within the arrayref $primes, accessible by the array index; the 
@@ -51,22 +51,22 @@ prime numbers of the first range may be accessed by @{$primes->[0]}.
 =cut
 
 sub prime {
-    my ($ranges) = @_;
-    croak 'usage: prime( \@ranges )' unless @$ranges;
+    my (@ranges) = @_;
+    croak 'usage: prime( @ranges )' unless @ranges;
     	
     my (%composite, @primes);
     
-    for (my $s = 0; $s < @$ranges; $s++) {
-        for (my $i = 2; $i <= $ranges->[$s][1]; $i++) {
+    for (my $s = 0; $s < @ranges; $s++) {
+        for (my $i = 2; $i <= $ranges[$s][1]; $i++) {
             next if $composite{$i};
 	    
 	    my $calc = 0;	
-	    for (my $c = 2; $calc <= $ranges->[$s][1]; $c++)  {
+	    for (my $c = 2; $calc <= $ranges[$s][1]; $c++)  {
 	        $calc = $i * $c;
 	        $composite{$calc} = 1;
 	    }
 	    
-	    if ($i > $ranges->[$s][0]) {
+	    if ($i > $ranges[$s][0]) {
                 push @{$primes[$s]}, $i;
             }
         }
